<?xml version="1.0" encoding="UTF-8"?>
<!-- 
	Beta1_to_Beta2.xslt
	
	Converts Office 12 Beta 1 XML to Beta 2 XML.
	
	Owner: tomun
-->
<xsl:stylesheet 
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:relsB2="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:oartB1="http://schemas.microsoft.com/office/officeart/2005/8/oartml"
	xmlns:oartB2="http://schemas.openxmlformats.org/drawingml/2006/3/main"
	xmlns:pptB2="http://schemas.openxmlformats.org/presentationml/2006/3/main"
	xmlns:igxLayoutB1="http://schemas.microsoft.com/office/officeart/2005/8/layout"
	xmlns:dgm="http://schemas.openxmlformats.org/drawingml/2006/3/diagram" 
	xmlns:igxGrB1="http://schemas.microsoft.com/office/officeart/2005/8/graphic"
	xmlns:xdrB2="http://schemas.openxmlformats.org/drawingml/2006/3/spreadsheetDrawing" 
	>

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no"/>

	<!-- text, comments, pi's or any other node types -->
	<xsl:template match="node()">
		<xsl:copy/>
	</xsl:template>

	<!-- attributes -->
	<xsl:template match="@*">
		<!-- output a space -->
		<xsl:text> </xsl:text>
		<!-- output the attribute name -->
		<xsl:value-of select="name()"/>
		<!-- output the ' =" ' -->
		<xsl:text>=</xsl:text>
		<xsl:choose>
			<!-- does the attribute value contain a quote char? -->
			<xsl:when test="contains(., '&quot;')">
				<xsl:text disable-output-escaping="yes">&apos;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text disable-output-escaping="yes">&quot;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<!-- output the attribute value -->
		<xsl:value-of select="."/>
		<!-- output the closing quote -->
		<xsl:choose>
			<!-- does the attribute value contain a quote char? -->
			<xsl:when test="contains(., '&quot;')">
				<xsl:text disable-output-escaping="yes">&apos;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text disable-output-escaping="yes">&quot;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- OART Theme element officeStyleSheet->theme -->
	<xsl:template match="oartB2:officeStyleSheet | oartB2:theme">
		<xsl:param name="nsDecls"/>

		<xsl:element name="oartB2:theme">
			<!-- output the attributes and child elements -->
			<xsl:apply-templates select="node() | * | @*"/>

			<!-- Add extraClrSchemeLst element.  Move all clrStyle elements under here, and rename to extraClrScheme -->
			<xsl:element name="oartB2:extraClrSchemeLst">
				<xsl:for-each select="oartB2:clrStyle">
					<xsl:element name="oartB2:extraClrScheme">
						<xsl:copy-of select="node() | * | @*"/>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>

			<!-- Move custClrLst out of baseStyles -->
			<xsl:if test="oartB2:baseStyles/oartB2:custClrLst">
				<xsl:element name="oartB2:custClrLst">
					<xsl:apply-templates select="oartB2:baseStyles/oartB2:custClrLst/node() | oartB2:baseStyles/oartB2:custClrLst/* | oartB2:baseStyles/oartB2:custClrLst/@*"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>

	<!-- NOP to mask old notesStyle element -->
	<xsl:template match="pptB2:txStyles/pptB2:notesStyle" />

	<!-- NOP to mask old custClrLst location -->
	<xsl:template match="oartB2:baseStyles/oartB2:custClrLst" />

	<!-- NOP to mask old clrStyle location -->
	<xsl:template match="oartB2:officeStyleSheet/oartB2:clrStyle" />

	<!-- OART Theme element ossOverride->themeOverride -->
	<xsl:template match="oartB2:ossOverride | oartB2:themeOverride">
		<xsl:param name="nsDecls"/>

		<xsl:element name="oartB2:themeOverride">
			<!-- output the attributes and child elements -->
			<xsl:apply-templates select="node() | * | @*"/>
		</xsl:element>
	</xsl:template>

	<!-- OART Theme element baseStyles->themeElements -->
 	<xsl:template match="oartB2:baseStyles | oartB2:themeElements">
		<xsl:param name="nsDecls"/>

		<xsl:element name="oartB2:themeElements">
			<!-- output the attributes and child elements -->
			<xsl:apply-templates select="node() | * | @*"/>
		</xsl:element>
	</xsl:template>

	<!-- OART Animation element grLayout->dgm -->
	<xsl:template match="oartB2:grLayout | oartB2:dgm">
		<xsl:element name="oartB2:dgm">
			<!-- output the attributes -->
			<xsl:copy-of select="@*"/>
		</xsl:element>
	</xsl:template>

	<!-- OART Animation element bldGrLayout->bldDgm -->
	<xsl:template match="oartB2:bldGrLayout | oartB2:bldDgm">
		<xsl:element name="oartB2:bldDgm">
			<!-- output the attributes -->
			<xsl:copy-of select="@*"/>
		</xsl:element>
	</xsl:template>

	<!-- OART element audioFile with non-empty embed attribute->wavAudioFile; 
	     OART element audioFile with empty embed attribute->remove embed attribute -->
	<xsl:template match="oartB2:audioFile">
		<xsl:choose>
			<xsl:when test="@relsB2:embed != ''">
				<xsl:element name="oartB2:wavAudioFile">
					<!-- output the attributes -->
					<xsl:copy-of select="@*"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:copy-of select="@relsB2:link"/>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- OART element videoFile - remove embed attribute (only link attribute is valid) -->
	<xsl:template match="oartB2:videoFile">
		<xsl:copy>
			<xsl:copy-of select="@relsB2:link"/>
		</xsl:copy>
	</xsl:template>

	<!-- Mask out prot element on OART CT_TextBodyProperties -->
	<xsl:template match="oartB2:prot" />

	<!-- NO OP to mask old outline text styles location -->
	<xsl:template match="oartB2:outline1pPr" />
	<xsl:template match="oartB2:outline2pPr" />

	<!-- NO OP to mask math objects -->
	<xsl:template match="oartB2:math" />

	<!-- IGX element bulEnabled->bulletEnabled -->
	<xsl:template match="igxGrB1:bulEnabled | igxLayoutB1:bulEnabled | dgm:bulEnabled">
		<xsl:param name="nsDecls"/>

		<xsl:element name="dgm:bulletEnabled">
			<!-- output the attributes -->
			<xsl:copy-of select="@*"/>
		</xsl:element>
	</xsl:template>

	<!-- IGX axis attribute values 'desOrSlf'->'desOrSelf' and 'ancstOrSlf'->'ancstOrSelf' -->
	<xsl:template match="igxLayoutB1:presOf/@axis | dgm:presOf/@axis |
						 igxLayoutB1:forEach/@axis | dgm:forEach/@axis | 
						 igxLayoutB1:if/@axis | dgm:if/@axis">

		<xsl:variable name="axisVal">
			<xsl:call-template name="replace-string">
				<xsl:with-param name="text" select="."/>
				<xsl:with-param name="from" select="'desOrSlf'"/>
				<xsl:with-param name="to" select="'desOrSelf'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="axisVal2">
			<xsl:call-template name="replace-string">
				<xsl:with-param name="text" select="$axisVal"/>
				<xsl:with-param name="from" select="'ancstOrSlf'"/>
				<xsl:with-param name="to" select="'ancstOrSelf'"/>
			</xsl:call-template>
		</xsl:variable>

		<!-- output a space -->
		<xsl:text> </xsl:text>
		<!-- output the attribute name -->
		<xsl:value-of select="name()"/>
		<!-- output the ' ="val" ' -->
		<xsl:text>=&quot;</xsl:text>
		<xsl:value-of select="$axisVal2"/>
		<xsl:text>&quot;</xsl:text>
	</xsl:template>

	<!-- oart paragraph indent level attribute values -1 and -2 are ignored -->
	<xsl:template match="oartB2:pPr[@lvl='-1' or @lvl='-2']/@lvl">
	</xsl:template>

	<!-- oart autonumber bullet startAt attribute of 0 is ignored -->
	<xsl:template match="oartB2:buAutoNum[@startAt='0']/@startAt">
	</xsl:template>

	<!-- elements -->
	<xsl:template match="*">
		<xsl:param name="nsDecls"/>

		<!-- output the less-than sign and the element name -->
		<xsl:text disable-output-escaping="yes">&lt;</xsl:text>
		<xsl:value-of select="name()"/>

		<!-- output the namespace declaration attributes filtering out ones already declared by ancestors -->
		<xsl:for-each select="namespace::node()">
			<!-- put each namespace decl into a variable -->
			<xsl:variable name="nsDecl">
				<xsl:if test="name() != 'xml'">
					<!-- output a space and then xmlns -->
					<xsl:text> xmlns</xsl:text>
					<xsl:if test="name() != ''">
						<!-- output a colon -->
						<xsl:text>:</xsl:text>
						<!-- output the prefix name -->
						<xsl:value-of select="name()"/>
					</xsl:if>
					<!-- output the ' =" ' -->
					<xsl:text disable-output-escaping="yes">=&quot;</xsl:text>
					<!-- output the namespace uri -->
					<xsl:value-of select="."/>
					<!-- output the closing quote -->
					<xsl:text disable-output-escaping="yes">&quot;</xsl:text>
				</xsl:if>
			</xsl:variable>
			<!-- output only if not already declared by an ancestor -->
			<xsl:if test="not(contains($nsDecls, $nsDecl))">
				<!-- output a space and then xmlns -->
				<xsl:text> xmlns</xsl:text>
				<xsl:if test="name() != ''">
					<!-- output a colon -->
					<xsl:text>:</xsl:text>
					<!-- output the prefix name -->
					<xsl:value-of select="name()"/>
				</xsl:if>
				<!-- output the ' =" ' -->
				<xsl:text disable-output-escaping="yes">=&quot;</xsl:text>
				<!-- output the namespace uri -->
				<xsl:choose>
					<xsl:when test=". = 'http://schemas.microsoft.com/office/officeart/2005/8/colors'">
						<xsl:text>http://schemas.openxmlformats.org/drawingml/2006/3/diagram</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'http://schemas.microsoft.com/office/officeart/2005/8/data'">
						<xsl:text>http://schemas.openxmlformats.org/drawingml/2006/3/diagram</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'http://schemas.microsoft.com/office/officeart/2005/8/graphic'">
						<xsl:text>http://schemas.openxmlformats.org/drawingml/2006/3/diagram</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'http://schemas.microsoft.com/office/officeart/2005/8/layout'">
						<xsl:text>http://schemas.openxmlformats.org/drawingml/2006/3/diagram</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'http://schemas.microsoft.com/office/officeart/2005/8/quickstyle'">
						<xsl:text>http://schemas.openxmlformats.org/drawingml/2006/3/diagram</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'http://schemas.microsoft.com/office/officeart/2005/8/oartml'">
						<xsl:text>http://schemas.openxmlformats.org/drawingml/2006/3/main</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- output the closing quote -->
				<xsl:text disable-output-escaping="yes">&quot;</xsl:text>
			</xsl:if>
		</xsl:for-each>

		<!-- output the attributes -->
		<xsl:apply-templates select="@*"/>

		<xsl:choose>
			<!-- does this element have children or text? -->
			<xsl:when  test="count(* | node())">
				<!-- output the closing greater-than sign -->
				<xsl:text disable-output-escaping="yes">&gt;</xsl:text>

				<!-- make a variable that contains *all* the namespace declaration for this element -->
				<xsl:variable name="curNsDecls">
					<xsl:for-each select="namespace::node()">
						<xsl:if test="name() != 'xml'">
							<!-- output a space and then xmlns -->
							<xsl:text> xmlns</xsl:text>
							<xsl:if test="name() != ''">
								<!-- output a colon -->
								<xsl:text>:</xsl:text>
								<!-- output the prefix name -->
								<xsl:value-of select="name()"/>
							</xsl:if>
							<!-- output the ' =" ' -->
							<xsl:text disable-output-escaping="yes">=&quot;</xsl:text>
							<!-- output the namespace uri -->
							<xsl:value-of select="."/>
							<!-- output the closing quote -->
							<xsl:text disable-output-escaping="yes">&quot;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>

				<!-- output the child element and/or text -->
				<xsl:apply-templates select="node()">
					<xsl:with-param name="nsDecls" select="$curNsDecls"/>
				</xsl:apply-templates>

				<!-- output the closing element tag -->
				<xsl:text disable-output-escaping="yes">&lt;/</xsl:text>
				<xsl:value-of select="name()"/>
				<xsl:text disable-output-escaping="yes">&gt;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- output the closing slash and greater-than sign -->
				<xsl:text disable-output-escaping="yes">/&gt;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- document root -->
	<xsl:template match="/" >
		<xsl:apply-templates select="@* | node()"/>
	</xsl:template>

	<!-- search and replace function -->
	<xsl:template name="replace-string">
		<xsl:param name="text"/>
		<xsl:param name="from"/>
		<xsl:param name="to"/>

		<xsl:choose>
			<xsl:when test="contains($text, $from)">
				<xsl:variable name="before" select="substring-before($text, $from)"/>
				<xsl:variable name="after" select="substring-after($text, $from)"/>
				<xsl:variable name="prefix" select="concat($before, $to)"/>

				<xsl:value-of select="$before"/>
				<xsl:value-of select="$to"/>
				<xsl:call-template name="replace-string">
					<xsl:with-param name="text" select="$after"/>
					<xsl:with-param name="from" select="$from"/>
					<xsl:with-param name="to" select="$to"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- XLDR element extents->ext -->
	<xsl:template match="xdrB2:extents | xdrB2:ext">
		<xsl:element name="xdrB2:ext">
			<!-- output the attributes -->
			<xsl:copy-of select="@*"/>
			<!-- output the child elements -->
			<xsl:apply-templates select="node() | *"/>
		</xsl:element>
	</xsl:template>

</xsl:stylesheet>
